==> Iuppiter-3.6.13.13282.tar.gz: Iuppiter-3.6.13.13282/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: setup.py 13282 2021-08-30 12:58:19Z Tiffany $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, and individual contributors.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   1. Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#   3. Neither the name of Nuwa Information nor the names of its contributors
#      may be used to endorse or promote products derived from this software
#      without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# $Author: Tiffany $ (last)
# $Date: 2021-08-30 20:58:19 +0800 (週一, 30 八月 2021) $
# $Revision: 13282 $

# Eat our own dog food.

from sys import platform as _platform

from Iuppiter.DistUtil import setup

extraRequirements = [
]

import sys

# There is no gui in Linux environment and we only use pycrust with wxpython.
# Moreover, wxpython cannot be installed in Linux, so it is not required in
# Linux environment.
# Possible platform value: http://stackoverflow.com/questions/446209/
# possible-values-from-sys-platform
if _platform == "win32" or _platform == "darwin":
    extraRequirements.append("pip install wxPython")
    
setup(
    'Iuppiter',
    description='Utilities for all Nuwa company developed projects.',
    version='%s.%s' % ('3.6.13', "$Revision: 13282 $"[11:-2]),
    license='New BSD License',
    author='Nuwa Information Co., Ltd',
    author_email='bear@nuwainfo.com',
    url='http://www.nuwainfo.com/',
    zip_safe=False,
    extraRequirements=extraRequirements,
    extrasRequire={
        'test': 'REQUIREMENTS_TEST.txt',
    }
)

==> Iuppiter-4.1.0.13367.tar.gz: Iuppiter-4.1.0.13367/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: setup.py 13367 2021-12-24 04:53:31Z Mint $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, and individual contributors.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   1. Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#   3. Neither the name of Nuwa Information nor the names of its contributors
#      may be used to endorse or promote products derived from this software
#      without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# $Author: Mint $ (last)
# $Date: 2021-12-24 12:53:31 +0800 (Fri, 24 Dec 2021) $
# $Revision: 13367 $

# Eat our own dog food.

import os
from sys import platform as _platform

from Iuppiter.DistUtil import setup

extraRequirements = [
]

import sys

# There is no gui in Linux environment and we only use pycrust with wxpython.
# Moreover, wxpython cannot be installed in Linux, so it is not required in
# Linux environment.
# Possible platform value: http://stackoverflow.com/questions/446209/
# possible-values-from-sys-platform
if _platform == "win32" or _platform == "darwin":
    extraRequirements.append("pip install wxPython")

# windows = ['wxPython']

setup(
    'Iuppiter',
    description='Utilities for all Nuwa company developed projects.',
    version='%s.%s' % ('4.1.0', "$Revision: 13367 $"[11:-2]),
    license='New BSD License',
    author='Nuwa Information Co., Ltd',
    author_email='bear@nuwainfo.com',
    url='http://www.nuwainfo.com/',
    zip_safe=False,
    extraRequirements=extraRequirements,
    extrasRequire={
        'test': 'REQUIREMENTS_TEST.txt',
    }
)

# pip install Iuppiter[windows]
# os.system(f'pip install {Iuppiter[windows]}')
